@@ -303,7 +303,7 @@ def backup():
             
 
 
-def update_infodb(valor_atualizar, just_append=False, path_dir_=None, antiblock=False):
+def update_infodb(valor_atualizar, just_append=True, path_dir_=None, antiblock=False):
     global editando
     if client_use:
         if type(valor_atualizar) == str:
@@ -322,7 +322,7 @@ def update_infodb(valor_atualizar, just_append=False, path_dir_=None, antiblock=
             global path_dir
         else:
             path_dir = path_dir_
-        testa_existe_info = dirfdb(antiblock=True)
+        testa_existe_info = dirfdb(antiblock=True, return_pathed=False)
         if just_append == False:
             qntd_infos_path = len(path_dir)
             if qntd_infos_path == 0:
@@ -336,7 +336,7 @@ def update_infodb(valor_atualizar, just_append=False, path_dir_=None, antiblock=
                     return
                 
             contador_exect = 1
-            dict_pushed = dirfdb(antiblock=True)
+            dict_pushed = dirfdb(antiblock=True, return_pathed=False)
             if dict_pushed == None:
                 dict_saved_in_db = nested_dict()
             else:
@@ -358,7 +358,7 @@ def update_infodb(valor_atualizar, just_append=False, path_dir_=None, antiblock=
                 editando = False
         elif just_append == True and type(valor_atualizar) == dict:
             for k, v in valor_atualizar.items():
-                temp_list = path_dir_
+                temp_list = path_dir
                 temp_list.append(k)
                 atualiza_infodb(v, antiblock=True, path_dir_=temp_list)
             editando = False
@@ -512,7 +512,7 @@ def inicia_db(path_to_jsontiny='', key_decript=b'', client_server=False, host_se
                 is_closed = False
         
         try:
-            dirfdb()
+            dirfdb(return_pathed=False)
         except:
             raise DatabaseEncrypted('Database is encrypted!')
         buscador_db = Query()
@@ -592,7 +592,7 @@ def close(travar=False):
             
             editando = False
 
-def dirfdb(searchdb=None, antiblock=False, path_dir_=None):
+def dirfdb(searchdb=None, antiblock=False, path_dir_=None, return_pathed=True):
     global editando
     if client_use:
         client.send('dirfdb'.encode('utf-8'))
@@ -610,7 +610,7 @@ def dirfdb(searchdb=None, antiblock=False, path_dir_=None):
             path_dir = path_dir_
         if searchdb != None:
             path_dir.append(searchdb)
-            db = dirfdb(antiblock=True)
+            db = dirfdb(antiblock=True, return_pathed=False)
             for path_use in path_dir:
                 db = db[path_use]
             editando = False
@@ -620,7 +620,16 @@ def dirfdb(searchdb=None, antiblock=False, path_dir_=None):
             if len(data_tinydb_storade) > 0:
                 if antiblock == False:
                     editando = False
-                return data_tinydb_storade[0]
+                if return_pathed:
+                    data_pushed_tiny = data_tinydb_storade[0]
+                    try:
+                        for item in path_dir:
+                            data_pushed_tiny = data_pushed_tiny[item]
+                        return data_pushed_tiny
+                    except:
+                        return data_pushed_tiny
+                else:
+                    return data_tinydb_storade[0]
             else:
                 if antiblock == False:
                     editando = False
@@ -667,13 +676,15 @@ def cdadd(path_to_update, replace_all_path=False, path_dir_=None):
                 for item_path_new in path_to_update:
                     path_dir.append(item_path_new)
         else:
+            if len(path_to_update) > 1 and '/' in path_to_update:
+                return cdadd(path_to_update.split('/'), True)
+                
             if replace_all_path:
                 path_dir = []
                 if path_to_update != '-' or path_to_update != '/':
                     path_dir.append(path_to_update)
             else:
-                print(path_to_update)
-                if path_to_update == '-' or path_dir == '/':
+                if path_to_update == '-' or path_to_update == '/':
                     path_dir = []
                 else:
                     path_dir.append(path_to_update)
@@ -700,7 +711,7 @@ def remove_infodb(path_delete=None, path_dir_=None, antiblock=False):
         if type(path_delete) != list:
             raise TypeError('Path to delete must be a list!')
         global contador_exec
-        db_delete = dirfdb(antiblock=True)
+        db_delete = dirfdb(antiblock=True, return_pathed=False)
         if db_delete == None:
             pass
         else:
@@ -777,13 +788,13 @@ def cdmin(qntd_min=1, path_dir_=None):
         return path_dir
 
 def dirfdbp():
-    tempor = dirfdb()
+    tempor = dirfdb(return_pathed=False)
     if tempor != None:
-        print(dumps(dirfdb(), indent=4, ensure_ascii=False).encode('utf-8').decode())
+        print(dumps(dirfdb(return_pathed=False), indent=4, ensure_ascii=False).encode('utf-8').decode())
     else:
         print(None)
 
 #inicia_db('Teste_backup_drop111.json', b'FXRO1m_RLfY9witk54XTyf_Q0R1iMSKVdXI0SRqft40=', False, True, '10.1.1.165', 7777, 'sl.BRd0er5tzHhBwyLuxts38anKKYyr3SdBkuoIWzmpfH5Qs8WtwDndziiIdtHi2CiiL-C1-YRAZZUbxy-sUbiKOk79KjI9g-2InwwvVEFeH_wLXu6r3cPvCUW-oUdoJxVBd6bohbW8Nxo')
 #inicia_db(client_server=True, ip_host_server='10.1.1.165', port_host_server=7777)
 #inicia_host('Teste_backup_drop111.json', 'localhost', 7777, b'FXRO1m_RLfY9witk54XTyf_Q0R1iMSKVdXI0SRqft40=', 'sl.BRd0er5tzHhBwyLuxts38anKKYyr3SdBkuoIWzmpfH5Qs8WtwDndziiIdtHi2CiiL-C1-YRAZZUbxy-sUbiKOk79KjI9g-2InwwvVEFeH_wLXu6r3cPvCUW-oUdoJxVBd6bohbW8Nxo')
-#inicia_client('localhost', 7777, b'FXRO1m_RLfY9witk54XTyf_Q0R1iMSKVdXI0SRqft40=')
\ No newline at end of file
+#inicia_client('localhost', 7777, b'FXRO1m_RLfY9witk54XTyf_Q0R1iMSKVdXI0SRqft40=')
